<?php
namespace Ep\WordPress\Service;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu MetadataServicea
 *
 * @package Ep\WordPress\Service
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class MetadataServiceFactory implements FactoryInterface
{
	/**
	 * Stvara objekt
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$service = new MetadataService($container);

		$config = $container->get('config');
		$wpConfig = $config['wordpress'] ?? [];
		$providers = $wpConfig['metadata_providers'] ?? [];

		foreach ($providers as $provider) {
			if (!$container->has($provider)) {
				throw new ServiceNotCreatedException(sprintf(
					"Invalid metadata provider '%s'.", $provider
				));
			}

			/** @var MetadataProviderInterface $provider */
			$provider = $container->get($provider);

			if (!$provider instanceof MetadataProviderInterface) {
				throw new ServiceNotCreatedException(sprintf(
					"Invalid metadata provider type expected MetadataProviderInterface, got %s",
					is_object($provider) ? get_class($provider) : gettype($provider)
				));
			}

			$service->addProvider($provider);
		}

		return $service;
	}
}