<?php
namespace Ep\WordPress;

use Ep\WordPress\Service\WordPressServiceInterface;

/**
 * Upravlja WordPressom.
 *
 * @package Ep\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class WordPressManager implements WordPressServiceInterface
{
	/** @var WordPressServiceInterface[] */
	protected $services = [];

	/**
	 * Dodaje WP servis.
	 *
	 * @param WordPressServiceInterface $service
	 */
	public function addService(WordPressServiceInterface $service)
	{
		$this->services[] = $service;
	}

	/**
	 * Pokreće se prilikom aktivacije plugina.
	 */
	public function activate(): void
	{
		foreach ($this->services as $service) {
			$service->activate();
		}
	}

	/**
	 * Pokreće se prilikom deaktivacije plugina.
	 */
	public function deactivate(): void
	{
		foreach ($this->services as $service) {
			$service->deactivate();
		}
	}

	/**
	 * Dodaje handlere na WP akcije i filtere.
	 */
	public function attach(): void
	{
		foreach ($this->services as $service) {
			$service->attach();
		}
	}

	/**
	 * Dodaje handlere za akcije i filtere u adminu.
	 */
	public function attachAdmin(): void
	{
		foreach ($this->services as $service) {
			$service->attachAdmin();
		}
	}

	/**
	 * Uklanja handlere s WP akcija i filtera.
	 */
	public function detach(): void
	{
		foreach ($this->services as $service) {
			$service->detach();
		}
	}

	/**
	 * Uklanja handlere s akcija i filtera u adminu.
	 */
	public function detachAdmin(): void
	{
		foreach ($this->services as $service) {
			$service->detachAdmin();
		}
	}

	/**
	 * Dodaje front-end resurse.
	 */
	public function assets(): void
	{
		foreach ($this->services as $service) {
			$service->assets();
		}
	}

	/**
	 * Dodaje front-end resurse u adminu.
	 */
	public function adminAssets(): void
	{
		foreach ($this->services as $service) {
			$service->adminAssets();
		}
	}
}